==> haskell-named-text-1.2.1.0-58-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-named-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.1.0
visibility:           public
id:                   named-text-1.2.1.0-CDlnEnVp1w0F7zFjZyNLOK
key:                  named-text-1.2.1.0-CDlnEnVp1w0F7zFjZyNLOK
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  fb4f3af212514097aa7e9674f9bb99fb
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.1.0-CDlnEnVp1w0F7zFjZyNLOK
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg
    sayable-1.2.5.0-Htl6e9utMda8m5li9o41ut text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-named-text-1.2.1.0-80-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-named-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.1.0
visibility:           public
id:                   named-text-1.2.1.0-GAFJH1Pik6ZHyojryDvg1H
key:                  named-text-1.2.1.0-GAFJH1Pik6ZHyojryDvg1H
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  83ff27b8f52001c3492fb02a4ae453b0
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/named-text-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.1.0-GAFJH1Pik6ZHyojryDvg1H
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7
    sayable-1.2.5.0-2tbdHmZEwmK2XWiyL5dl6A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
